title: Recherche
tags: 

## Rechercher

### Recherche simple

Un champ de recherche unique combine tous les termes de recherches et fournit une liste de résultats triée par pertinence. Ceux-ci peuvent ensuite être filtrés au moyen [des facettes](#filtrer-sa-recherche).

### Astuces de recherche

| Symbole | Description| Exemple | Effet |
|:---:|---|---|---|
| `*` | Troncature | `culture*` | Recherche les ressources commençant par "culture", comme "culture", "culturel", "culturelle", etc. |
| `+` | Opérateur booléen ET | `chien + chat` | Recherche les ressources contenant "chien" et aussi "chat". Si rien est spécifié, l'opérateur ET s'appliquera de toute façon. |
| `|` | Opérateur booléen OU | `vélo | bicyclette` | Recherche les ressources contenant soit "vélo", soit "bicyclette" |
| `-` | Opérateur booléen SAUF | `tintin -tibet` | Recherche les ressources contenant "tintin" mais pas "tibet". Le mot à exclure doit être collé au signe `-`. |
| `()` | Parenthèses, pour combiner les opérateurs | `mobilité + (vélo | bicyclette)` | Recherche les ressources contenant "mobilité" et soit "vélo", soit "bicyclette" |
| `""` | Expression exacte | `"revue littéraire"` | Recherche les ressources contenant l'expression exacte "revue littéraire" |

### Onglets de résultats

Le formulaire de recherche permet de trouver non seulement des documents, mais également des personnes ou collectivités afin, par exemple, d'obtenir des informations sur un auteur et de lister les documents qui lui sont liés.

### Filtrer sa recherche

Les facettes permettent de filtrer les résultats selon différents critères tels que: type de document, auteur, bibliothèque, etc. En un clic, les facettes restreignent la recherche de plusieurs milliers de résultats.

Comme les poupées russes, les facettes peuvent se combiner, l'ensemble des résultats se restreignant toujours plus. Les sélections initiales restant actives tant qu'elles ne sont pas enlevées (dans le cadre de la même recherche). 

### Vue détaillée d'un document

Pour afficher des informations détaillées sur un document, cliquer sur son titre dans les résultats de recherche. La vue détaillée contient des informations sous différents onglets :

* __Obtenir :__ Affiche les exemplaires des bibliothèques, leur statut et leur disponibilité, et permet d'effectuer une demande ou une réservation. 
* __Description :__ Contient les informations bibliographiques détaillées concernant le document. 

## S'inscrire

Pour vous inscrire, veuillez vous rendre dans la bibliothèque de votre choix.

Si vous le souhaitez, vous pouvez déjà vous créer un compte en ligne et saisir vos données personnelles, ce qui accélérera votre inscription sur place:

1. Cliquer sur  **<i aria-hidden="true" class="fa fa-user"></i> Mon compte** > **<i aria-hidden="true" class="fa fa-user-plus"></i> S'inscrire**
1. Introduire e-mail et mot de passe
1. Cliquer sur  **<i aria-hidden="true" class="fa fa-user"></i> Mon compte** > **<i aria-hidden="true" class="fa fa-user"></i> Éditer mon profil**
1. Saisir vos données personnelles
1. Sauvegarder et vous rendre dans la bibliothèque de votre choix

## Gérer son compte

### Se connecter

La connexion vous permet de consulter l'état de votre compte lecteur (documents empruntés, réservés, en retard…). Elle vous permet aussi de prolonger vous-même le délai de prêt des documents que vous avez empruntés.

* Cliquer sur  **<i aria-hidden="true" class="fa fa-user"></i> Mon compte** > **<i aria-hidden="true" class="fa fa-sign-in"></i> Se connecter**
* Entrer votre nom d'utilisateur ou e-mail, ainsi que votre mot de passe

La présence de votre nom en haut à droite de l'écran signifie que votre compte est ouvert.

### Compte lecteur et lectrice

Une fois que vous êtes connecté·e, votre compte est accessible depuis le menu en haut à droite **<i aria-hidden="true" class="fa fa-book"></i> Mon compte**. Les rubriques suivantes y sont proposées :

* __Emprunts :__ Liste de vos documents empruntés. Une bouton permet la prolongation de la date d'échéance des documents.
* __Demandes :__ Liste des documents demandés et des documents à retirer. Cette vue affiche également le statut des demandes en cours. Un bouton vous permet d'annuler une demande. 
* __Frais :__ Les différents frais que vous devez à votre bibliothèque (amendes, prêts entre bibliothèques, photocopies…).
* __Prêt entre bibliothèques :__ Liste des demandes et des prêts entre bibliothèques, ainsi que leurs statuts.
* __Historique :__ Les documents que vous avez empruntés et rendus. Cette liste est conservée pour une durée limitée.
* __Données personnelles :__ Les données personnelles de votre compte. 

### Modifier son mot de passe

1. Se connecter
1. Depuis le menu de votre compte, cliquer sur **<i aria-hidden="true" class="fa fa-lock"></i> Modifier le mot de passe**
1. Saisir l'ancien et le nouveau mot de passe, et valider

Si vous avez oublié votre mot de passe, vous pouvez utiliser la fonction "Mot de passe oublié" sur la page de connexion.

### Modifier ses données personnelles

1. Se connecter
1. Depuis le menu de votre compte, cliquer sur **<i aria-hidden="true" class="fa fa-user"></i> Éditer mon profil**
1. Vous pouvez modifier toutes les données excepté vos noms et date de naissance. Pour un changement de nom, adressez-vous à votre bibliothèque.

### Prolonger un document

1. Se connecter
1. Ouvrir son compte lecteur ou lectrice (en haut à droite)
1. Dans __Emprunts__, cliquer sur __Prolonger__

## Demander/réserver un document

Vous avez la possibilité de demander ou de réserver un document en ligne:

1. Se connecter
1. Rechercher le document souhaité
1. Dans l'onglet __Obtenir__, cliquer sur __Demander__
    * Si l'option __Demander__ ne s'affiche pas: soit la bibliothèque n'autorise pas les demandes sur cet exemplaire, soit vous n'êtes pas inscrit·e dans le réseau dans cette bibliothèque/réseau.
1. Sélectionner le lieu de retrait et valider

La demande/réservation peut concerner :

* Un exemplaire disponible
* Un exemplaire disponible hors du libre accès
* Un exemplaire hors du libre accès à consulter sur place uniquement
* Une réservation sur un exemplaire déjà emprunté par une autre personne.

## Prêt entre bibliothèques

Pour soumettre une demande:

1. Se connecter
1. Cliquer sur  **<i aria-hidden="true" class="fa fa-wrench"></i> Outils** > **<i aria-hidden="true" class="fa fa-shopping-basket"></i> Demande de prêt entre bibliothèques**
1. Remplir le formulaire en indiquant autant d'informations que possible
1. Sauvegarder

Les demandes s'affichent ensuite dans votre compte, onglet **Prêt entre bibliothèques**. 